==> xml-path-3.1.0-sources.jar: io/restassured/internal/path/xml/NodeImpl.java <==
package io.restassured.internal.path.xml;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class NodeImpl
  extends io.restassured.internal.path.xml.NodeBase  implements
    io.restassured.path.xml.element.Node {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getAttributes() { return null;}
public  void setAttributes(java.lang.Object value) { }
public  io.restassured.path.xml.element.NodeChildren getChildren() { return (io.restassured.path.xml.element.NodeChildren)null;}
public  void setChildren(io.restassured.path.xml.element.NodeChildren value) { }
public  java.lang.Object getName() { return null;}
public  void setName(java.lang.Object value) { }
public  java.lang.Object getValue() { return null;}
public  void setValue(java.lang.Object value) { }
public  java.lang.Object getGroovyNode() { return null;}
public  void setGroovyNode(java.lang.Object value) { }
@java.lang.Override() public  java.util.Map<java.lang.String, java.lang.String> attributes() { return (java.util.Map)null;}
@java.lang.Override() public  java.lang.String name() { return (java.lang.String)null;}
@java.lang.Override() public  java.util.Iterator<java.lang.String> iterator() { return (java.util.Iterator)null;}
public  java.lang.String toString() { return (java.lang.String)null;}
public  io.restassured.path.xml.element.Node get(int index) { return (io.restassured.path.xml.element.Node)null;}
public  io.restassured.path.xml.element.NodeChildren children() { return (io.restassured.path.xml.element.NodeChildren)null;}
public  java.lang.Object leftShift(io.restassured.path.xml.element.Node node) { return null;}
public  java.lang.String getAttribute(java.lang.String name) { return (java.lang.String)null;}
public  float getFloat(java.lang.String name) { return (float)0;}
public  double getDouble(java.lang.String name) { return (double)0;}
public  char getChar(java.lang.String name) { return (char)0;}
public  boolean getBoolean(java.lang.String name) { return false;}
public  long getLong(java.lang.String name) { return (long)0;}
public  int getInt(java.lang.String name) { return (int)0;}
public  short getShort(java.lang.String name) { return (short)0;}
public  byte getByte(java.lang.String name) { return (byte)0;}
public <T> T get(java.lang.String name) { return null;}
@java.lang.Override() public <T> T getPath(java.lang.String path) { return null;}
@java.lang.Override() public  java.lang.String value() { return (java.lang.String)null;}
@java.lang.Override() public <T> java.util.List<T> getList(java.lang.String name) { return (java.util.List)null;}
@java.lang.Override() public  java.lang.Object getBackingGroovyObject() { return null;}
public class ValueIterator
  extends java.lang.Object  implements
    java.util.Iterator<java.lang.String>,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getHasNext() { return null;}
public  void setHasNext(java.lang.Object value) { }
@java.lang.Override() public  boolean hasNext() { return false;}
@java.lang.Override() public  java.lang.String next() { return (java.lang.String)null;}
@java.lang.Override() public  void remove() { }
}
}

==> xml-path-4.2.0-sources.jar: io/restassured/internal/path/xml/NodeImpl.java <==
package io.restassured.internal.path.xml;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class NodeImpl
  extends io.restassured.internal.path.xml.NodeBase  implements
    io.restassured.path.xml.element.Node {
public  java.lang.Object getAttributes() { return null;}
public  void setAttributes(java.lang.Object value) { }
public  io.restassured.path.xml.element.NodeChildren getChildren() { return (io.restassured.path.xml.element.NodeChildren)null;}
public  void setChildren(io.restassured.path.xml.element.NodeChildren value) { }
public  java.lang.Object getName() { return null;}
public  void setName(java.lang.Object value) { }
public  java.lang.Object getValue() { return null;}
public  void setValue(java.lang.Object value) { }
public  java.lang.Object getGroovyNode() { return null;}
public  void setGroovyNode(java.lang.Object value) { }
public  java.util.Map attributes() { return (java.util.Map)null;}
public  java.lang.String name() { return (java.lang.String)null;}
public  java.util.Iterator iterator() { return (java.util.Iterator)null;}
public  java.lang.String toString() { return (java.lang.String)null;}
public  io.restassured.path.xml.element.Node get(int index) { return (io.restassured.path.xml.element.Node)null;}
public  io.restassured.path.xml.element.NodeChildren children() { return (io.restassured.path.xml.element.NodeChildren)null;}
public  java.lang.Object leftShift(io.restassured.path.xml.element.Node node) { return null;}
public  java.lang.String getAttribute(java.lang.String name) { return (java.lang.String)null;}
public  float getFloat(java.lang.String name) { return (float)0;}
public  double getDouble(java.lang.String name) { return (double)0;}
public  char getChar(java.lang.String name) { return (char)0;}
public  boolean getBoolean(java.lang.String name) { return false;}
public  long getLong(java.lang.String name) { return (long)0;}
public  int getInt(java.lang.String name) { return (int)0;}
public  short getShort(java.lang.String name) { return (short)0;}
public  byte getByte(java.lang.String name) { return (byte)0;}
public  java.lang.Object get(java.lang.String name) { return null;}
public  java.lang.Object getPath(java.lang.String path) { return null;}
public  java.lang.String value() { return (java.lang.String)null;}
public <T> java.util.List getList(java.lang.String name) { return (java.util.List)null;}
public  java.lang.Object getBackingGroovyObject() { return null;}
public class ValueIterator
  extends java.lang.Object  implements
    java.util.Iterator,    groovy.lang.GroovyObject {
public  java.lang.Object getHasNext() { return null;}
public  void setHasNext(java.lang.Object value) { }
public  boolean hasNext() { return false;}
public  java.lang.String next() { return (java.lang.String)null;}
public  void remove() { }
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
}
}
